@@ -1,7 +1,9 @@
 package lib::disallow;
 
-our $DATE = '2016-08-24'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-20'; # DATE
+our $DIST = 'lib-filter'; # DIST
+our $VERSION = '0.28'; # VERSION
 
 use strict;
 use warnings;
@@ -33,7 +35,7 @@ lib::disallow - Disallow a list of modules from being locateable/loadable
 
 =head1 VERSION
 
-This document describes version 0.27 of lib::disallow (from Perl distribution lib-filter), released on 2016-08-24.
+This document describes version 0.28 of lib::disallow (from Perl distribution lib-filter), released on 2021-05-20.
 
 =head1 SYNOPSIS
 
@@ -61,7 +63,7 @@ Source repository is at L<https://github.com/perlancar/perl-lib-filter>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=lib-filter>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-lib-filter/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -81,7 +83,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
