@@ -1,10 +1,12 @@
 package lib::filter;
 
-our $DATE = '2016-08-24'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-20'; # DATE
+our $DIST = 'lib-filter'; # DIST
+our $VERSION = '0.28'; # VERSION
 
-# no need to avoid strict & warnings, because Config uses them
-use strict;
+use 5.008009;  # the first version where Module::CoreList becomes core
+use strict;    # no need to avoid strict & warnings, because Config uses them
 use warnings;
 use Config;
 
@@ -240,7 +242,7 @@ lib::filter - Allow/disallow loading modules
 
 =head1 VERSION
 
-This document describes version 0.27 of lib::filter (from Perl distribution lib-filter), released on 2016-08-24.
+This document describes version 0.28 of lib::filter (from Perl distribution lib-filter), released on 2021-05-20.
 
 =head1 SYNOPSIS
 
@@ -263,6 +265,8 @@ module exist, so I'll be presenting those in the examples below.
 
 You can also use L<lib::none> for this, or simply empty C<@INC>.
 
+To no-op instead of disallowing, see L<lib::noop::all>.
+
 =item * To allow only core modules:
 
 For example for testing a fatpacked script (see L<App::FatPacker>):
@@ -276,6 +280,8 @@ distribution.
 
  % perl -Mlib::filter=allow_core,0,allow_noncore,0,allow,'XSLoader;List::Util' yourscript.pl
 
+To no-op instead of disallowing, see L<lib::noop::except>.
+
 =item * To allow core modules plus some additional modules:
 
 For example to test a fatpacked script that might still require some XS modules:
@@ -319,6 +325,8 @@ L<Devel::Hide> is another module which you can you for exactly this purpose:
 
  % perl -MDevel::Hide=YAML::XS,JSON::XS yourscript.pl
 
+To no-op instead of disallowing, see L<lib::noop>.
+
 =item * Do custom filtering
 
  % perl -Mlib::filter=filter,sub{not/^Foo::/} yourscript.pl
@@ -428,7 +436,7 @@ Source repository is at L<https://github.com/perlancar/perl-lib-filter>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=lib-filter>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-lib-filter/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -442,13 +450,15 @@ L<Test::Without::Module>.
 To simulate the absence of certain programs in PATH, you can try
 L<File::Which::Patch::Hide>.
 
+To no-op instead of disallowing, see L<lib::noop>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
